//  **** BEGIN LICENSE BLOCK ****
//  Copyright(c) 2005-2006 Adam Judson
//
//
//  PhotoMap
//  - display user contributed photos in a map
//
//  This program is free software; you can redistribute it and/or modify it under
//  the terms of the GNU General Public License as published by the Free
//  Software Foundation; either version 2 of the License, or (at your option)
//  any later version.
//
//  This program is distributed in the hope that it will be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
//  more details.
//
//  You should have received a copy of the GNU General Public License along with
//  this program; if not, write to the Free Software Foundation, Inc., 59 Temple
//  Place, Suite 330, Boston, MA 02111-1307 USA
//
//  **** END LICENSE BLOCK ****


// base map implementation
function PhotoMapBaseMap() {
   // nothing here
}

PhotoMapBaseMap.prototype = {
   zoomLevels : 10,

   // called by sub-classes
   init : function() {
      this.observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
   },

   getURL : function(preferences) {
      return preferences.getMapURL();
   },

   getContent : function(preferences) {
      var home = preferences.getHome();
      var homeZoom = preferences.getHomeZoom();

      var content = '' +
            '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n' +
            '<html xmlns="http://www.w3.org/1999/xhtml" xmlns:v="urn:schemas-microsoft-com:vml">\n' +
            '  <head>\n' +
            '    <meta http-equiv="content-type" content="text/html; charset=UTF-8"/>\n' +
            '<style type="text/css">\n' +
            '   body {\n' +
            '      margin: 0px;\n' +
            '      border: 1px solid black;\n' +
            '   }\n' +
            '  #mapContainer { 	 \n' +
            '    height: 512px; 	  	 \n' +
            '    width: 512px; 	 \n' +
            '  } 	 \n' +
            '</style>\n' +
            this.getIncludes(preferences) +
            '    <script type="text/javascript">\n' +
            '    //<![CDATA[\n' +
            '\n' +
            this.getOnload(home.lat, home.lon, homeZoom) + 
            '\n' +
            this.getController() + 
            '\n' +
            '\n' +
            '    //]]>\n' +
            '    </script>\n' +
            '\n' +
            '  </head>\n' +
            '  <body onload="onLoad()">\n' +
            '    <div id="mapContainer" style="width: 512px; height: 512px"></div>\n' +
// crosshairs
// though doing them this way produces an dead spot for the mouse (actually, not dead, we can click and drag the 
// image, which is not what we want.
// 	         '    <!-- if we want crosshairs\n' +
//             '        <div id="mapTarget" style="position:absolute; left:256px; top: 256px; visibility:visble; z-Index:200"><img src="http://what should this be/target.png"></div>\n' +
//             '      -->\n' +         
            '  </body>\n' +
            '</html>\n';

      return content;
   },

   setZoom : function(zoom) {
      var location = this.getLocation();
      this.setLocation(location.lat, location.lon, this.convertToMapZoom(zoom));
   },

   setType : function(type) {
      PhotoMapUtils.log("Setting map type: " + type);
      if (type == "satellite") {
         if (this.setTypeSatellite) {
            this.setTypeSatellite();
         }
      } else if (type == "map") {
         if (this.setTypeMap) {
            this.setTypeMap();
         }
      } else if (type == "hybrid") {
         if (this.setTypeHybrid) {
            this.setTypeHybrid();
         } else {
            this.setType("satellite");
         }
      }
   },

   // move these out of the base if it doesn't make sense
   setTypeMap : function() {
      this.mapController.setMapTypeMap();
   },

   setTypeSatellite : function() {
      this.mapController.setMapTypeSatellite();
   },

   setTypeHybrid : function() {
      this.mapController.setMapTypeHybrid();
   },

   getType : function() {
      return this.mapController.getType();
   },

   create : function(iframe, preferences) {
      // if browser.cache.check_doc_frequency == 1, this will never work
      // loadURIWithFlags will also not work...
      iframe.setAttribute("src", this.getURL(preferences));
   },

   mapMoved : function(location, bounds) {
      this.observerService.notifyObservers(null,"photoMap-mapMoved", null);
   },

   markerSelected : function(lat, lon) {
      this.observerService.notifyObservers(null,"photoMap-markerSelected", lat + "x" + lon);
   },

   markerUnSelected : function(photo) {
      // nothing here
   }
};
